import requests
from bs4 import BeautifulSoup
import json
import re

def extract_email_content(html):
   """Trích xuất nội dung email thông minh"""
   soup = BeautifulSoup(html, 'html.parser')
   content = []
   verification_code = None

   # Tìm div chứa nội dung chính 
   content_div = soup.find('div', class_='mess_bodiyy')
   if content_div:
       # Tìm tất cả các đoạn text có ý nghĩa
       paragraphs = content_div.stripped_strings
       for text in paragraphs:
           text = text.strip()
           if text and not any(x in text.lower() for x in ['copyright', 'all rights', 'meta platform', 'menlo park']):
               content.append(text)
               # Check mã xác nhận
               if len(text) >= 4 and len(text) <= 8 and text.isdigit():
                   verification_code = text
               # Check trong nội dung
               elif ('mã' in text.lower() or 'code' in text.lower()) and ':' in text:
                   code_match = re.search(r'\d{4,8}', text.split(':')[-1])
                   if code_match:
                       verification_code = code_match.group()
               # Check các kiểu số khác
               elif 'mã' in text.lower() or 'code' in text.lower():
                   code_match = re.search(r'\d{4,8}', text) 
                   if code_match:
                       verification_code = code_match.group()

   return {
       'full_content': ' '.join(content),
       'verification_code': verification_code
   }

def read_email_detail(cookie_path):
    """Đọc nội dung chi tiết của email"""
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36",
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8",
        "Cookie": f"surl={cookie_path}"
    }
    
    try:
        response = requests.get("https://tempm.com/temp_mail_9/", headers=headers)
        if response.status_code == 200:
            return extract_email_content(response.text)
    except Exception as e:
        print(f"Lỗi khi đọc nội dung: {e}")
    return {'full_content': '', 'verification_code': None}
    
def extract_basic_email_info(element):
    """Trích xuất thông tin cơ bản của email"""
    # Tìm các div chứa thông tin từ người gửi, tiêu đề và thời gian
    from_div = element.find(lambda tag: tag.name == 'div' and 'from' in str(tag.get('class', [])).lower())
    subject_div = element.find(lambda tag: tag.name == 'div' and 'subj' in str(tag.get('class', [])).lower())
    time_div = element.find(lambda tag: tag.name == 'div' and 'time' in str(tag.get('class', [])).lower())
    
    if all([from_div, subject_div, time_div]):
        return {
            'from': from_div.get_text(strip=True),
            'subject': subject_div.get_text(strip=True),
            'time': time_div.get_text(strip=True)
        }
    return None



def get_emails(mail_domain, username):
    """Lấy thông tin email từ hòm thư"""
    url = "https://tempm.com/temp_mail_9/"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36",
        "Cookie": f"surl={mail_domain}/{username}"
    }
    
    try:
        response = requests.get(url, headers=headers)
        if response.status_code == 200:
            soup = BeautifulSoup(response.text, 'html.parser')
            email_table = soup.find('div', id='email-table')
            if not email_table:
                return []
            
            emails = []
            email_items = [item for item in email_table.find_all(['div', 'a']) 
                         if item.find('div') and 'adsbygoogle' not in str(item)]
            
            for item in email_items:
                email_info = extract_basic_email_info(item)
                if email_info:
                    href = item.get('href')
                    if href:
                        # Đọc nội dung chi tiết của email bằng cookie path từ href
                        cookie_path = href[1:] if href.startswith('/') else href
                        content = read_email_detail(cookie_path)
                        email_info.update({
                            'content': content['full_content'],
                            'verification_code': content['verification_code'],
                            'href': href
                        })
                    emails.append(email_info)
            
            return emails
            
    except Exception as e:
        print(f"Lỗi: {str(e)}")
    return []

def get_emails_json(domain, username):
    """Trả về kết quả dạng JSON"""
    emails = get_emails(domain, username)
    result = {
        "email": f"{username}@{domain}",
        "total_emails": len(emails),
        "emails": emails
    }
    return json.dumps(result, ensure_ascii=False, indent=2)

# Test
if __name__ == "__main__":
    print(get_emails_json("adgome.com", "usesr5771"))